import { AwsSdkSigV4AuthInputConfig, AwsSdkSigV4AuthResolvedConfig, AwsSdkSigV4PreviouslyResolved } from "@aws-sdk/core";
import { HandlerExecutionContext, HttpAuthScheme, HttpAuthSchemeParameters, HttpAuthSchemeParametersProvider, HttpAuthSchemeProvider } from "@smithy/types";
import { MediaPackageV2ClientResolvedConfig } from "../MediaPackageV2Client";
/**
 * @internal
 */
export interface MediaPackageV2HttpAuthSchemeParameters extends HttpAuthSchemeParameters {
    region?: string;
}
/**
 * @internal
 */
export interface MediaPackageV2HttpAuthSchemeParametersProvider extends HttpAuthSchemeParametersProvider<MediaPackageV2ClientResolvedConfig, HandlerExecutionContext, MediaPackageV2HttpAuthSchemeParameters, object> {
}
/**
 * @internal
 */
export declare const defaultMediaPackageV2HttpAuthSchemeParametersProvider: (config: MediaPackageV2ClientResolvedConfig, context: HandlerExecutionContext, input: object) => Promise<MediaPackageV2HttpAuthSchemeParameters>;
/**
 * @internal
 */
export interface MediaPackageV2HttpAuthSchemeProvider extends HttpAuthSchemeProvider<MediaPackageV2HttpAuthSchemeParameters> {
}
/**
 * @internal
 */
export declare const defaultMediaPackageV2HttpAuthSchemeProvider: MediaPackageV2HttpAuthSchemeProvider;
/**
 * @internal
 */
export interface HttpAuthSchemeInputConfig extends AwsSdkSigV4AuthInputConfig {
    /**
     * experimentalIdentityAndAuth: Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    httpAuthSchemes?: HttpAuthScheme[];
    /**
     * experimentalIdentityAndAuth: Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    httpAuthSchemeProvider?: MediaPackageV2HttpAuthSchemeProvider;
}
/**
 * @internal
 */
export interface HttpAuthSchemeResolvedConfig extends AwsSdkSigV4AuthResolvedConfig {
    /**
     * experimentalIdentityAndAuth: Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    readonly httpAuthSchemes: HttpAuthScheme[];
    /**
     * experimentalIdentityAndAuth: Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    readonly httpAuthSchemeProvider: MediaPackageV2HttpAuthSchemeProvider;
}
/**
 * @internal
 */
export declare const resolveHttpAuthSchemeConfig: <T>(config: T & HttpAuthSchemeInputConfig & AwsSdkSigV4PreviouslyResolved) => T & HttpAuthSchemeResolvedConfig;
